@@ -24,7 +24,7 @@ use Class::Accessor::Lite
     )]
 ;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub load_plugin {
     my ($class, $pkg, $opt) = @_;
@@ -453,7 +453,9 @@ sub delete {
 sub txn_manager  {
     my $self = shift;
     $self->_verify_pid;
-    $self->{txn_manager} ||= DBIx::TransactionManager->new($self->dbh);
+    $self->{txn_manager} ||= ($self->{txn_manager_class})
+        ? $self->{txn_manager_class}->new($self->dbh)
+        : DBIx::TransactionManager->new($self->dbh);
 }
 
 sub in_transaction_check {
@@ -840,6 +842,11 @@ instantiated for you.
 Specifies the schema class to use.
 By default {YOUR_MODEL_CLASS}::Schema is used.
 
+=item * C<txn_manager_class>
+
+Specifies the transaction manager class.
+By default DBIx::TransactionManager is used.
+
 =item * C<suppress_row_objects>
 
 Specifies the row object creation mode. By default this value is C<false>.
@@ -1062,7 +1069,7 @@ database disconnection.
 
 =item C<$txn_manager = $teng-E<gt>txn_manager>
 
-Get the DBIx::TransactionManager instance.
+Create the transaction manager instance with specified C<txn_manager_class>.
 
 =item C<$teng-E<gt>txn_begin>
 
